package App::RegexpPatternUtils;

our $DATE = '2018-03-21'; # DATE
our $VERSION = '0.003'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: CLI utilities related to Regexp::Pattern

__END__

=pod

=encoding UTF-8

=head1 NAME

App::RegexpPatternUtils - CLI utilities related to Regexp::Pattern

=head1 VERSION

This document describes version 0.003 of App::RegexpPatternUtils (from Perl distribution App-RegexpPatternUtils), released on 2018-03-21.

=head1 SYNOPSIS

=head1 DESCRIPTION

This distribution includes several utilities related to L<Regexp::Pattern>:

=over

=item * L<get-regexp-pattern-pattern>

=item * L<list-regexp-pattern-modules>

=item * L<list-regexp-pattern-patterns>

=item * L<show-regexp-pattern-module>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-RegexpPatternUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-RegexpPatternUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-RegexpPatternUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
